SystemOrganization addCategory: #'GT-SUnitDebugger'!

!Object methodsFor: '*GT-SUnitDebugger' stamp: 'AndreiChis 12/28/2015 20:22'!
gtDebuggerSUnitPrint
	"I return a textual representation of the object that is used by the SUnit debugger to compare objects using a textual diff."
	
	^ self printString! !

GTDebuggerContextPredicate subclass: #GTSUnitActivationPredicate
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitActivationPredicate commentStamp: 'AndreiChis 12/30/2015 10:47' prior: 0!
I decide when the SUnit debugger should be active.!

!GTSUnitActivationPredicate methodsFor: 'testing' stamp: 'AndreiChis 2/16/2016 15:21'!
matchContext: aContext
	
	^ aContext method isTestMethod! !

!Dictionary methodsFor: '*GT-SUnitDebugger' stamp: 'AndreiChis 12/28/2015 20:22'!
gtDebuggerSUnitPrint

	^ String streamContents: [ :aStream | 
		self keysSortedSafely
				do: [:key | aStream print: key;
						 space;
						 nextPutAll: '->';	
						 space;			
						 print: (self at: key);
						 cr]].! !

!String methodsFor: '*GT-SUnitDebugger' stamp: 'AndreiChis 12/28/2015 20:22'!
gtDebuggerSUnitPrint

	^ self printString! !

!DateAndTime methodsFor: '*GT-SUnitDebugger' stamp: 'AndreiChis 12/28/2015 20:22'!
gtDebuggerSUnitPrint

	^ String streamContents: [:s | self printSeparateDateAndTimeOn: s]! !

DebugSession subclass: #GTSUnitDebugSession
	instanceVariableNames: 'assertionContext expectedResult actualResult testContext assertionCallerContext'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitDebugSession commentStamp: 'AndreiChis 12/30/2015 10:44' prior: 0!
I am a debugging session for the SUnit debugger. 
I extract from the execution stack various data needed by the user interface of the SUnit debugger, like the test object and method.

Public API and Key Messages

- process:context: does the initialization of the session
- data is provided using the methods in the accessing protocol

    Instance Variables
	actualResult:		<Object>
	assertionContext:		<Object>
	expectedResult:		<Object>
	testObject:		<Object>!

!GTSUnitDebugSession class methodsFor: 'accessing' stamp: 'AndreiChis 12/4/2013 12:24'!
activationPredicate

	^  GTSUnitActivationPredicate new! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 12/17/2013 11:08'!
actualResult
	
	^ actualResult! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 23:09'!
assertionCallerContext

	^ assertionCallerContext! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 1/22/2016 18:44'!
assertionContext

	^ assertionContext! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 16:01'!
expectedResult
	
	^ expectedResult ! !

!GTSUnitDebugSession methodsFor: 'initialization' stamp: 'AndreiChis 1/22/2016 17:15'!
initializeAssestionContextFrom: aContext
	| frameworkTestClasses |
	
	frameworkTestClasses := {TestCase. TestCase superclass}.
	
	assertionContext := aContext findContextSuchThat: [ :anotherContext |
		anotherContext = testContext 
			ifTrue: [ 
				"the assestion context should be between the top context and before the test context"
				^ self  ].
		anotherContext sender notNil and: [ 
			 (frameworkTestClasses anySatisfy: [ :aTestClass |
				 aTestClass includesSelector: anotherContext sender method selector]) not ] ].
	assertionContext 
		ifNotNil: [ assertionCallerContext := assertionContext sender]
	
		! !

!GTSUnitDebugSession methodsFor: 'initialization' stamp: 'TudorGirba 2/8/2016 14:26'!
initializeTestContextFrom: aContext

	"we first try to find a test method in the stack"
	testContext := aContext findContextSuchThat: [ :anotherContext |
		anotherContext method isTestMethod ].
	
	testContext ifNil: [
		"if we do not find a test method, perhaps we are in the context of a different method, such as setUp, so we are looking for the last occurence of the test case instance in the stack"
		testContext := aContext findContextSuchThat: [ :anotherContext |
			anotherContext receiver class isTestCase ] ].
	
	testContext ifNil: [ 
		"if we did not find anything, we fallback to the default context"
		testContext := aContext ]! !

!GTSUnitDebugSession methodsFor: 'testing' stamp: 'AndreiChis 12/17/2013 11:12'!
isActive

	^ self isActive: self testContext! !

!GTSUnitDebugSession methodsFor: 'testing' stamp: 'AndreiChis 12/17/2013 11:11'!
isActive: aContext

	^ aContext 
		ifNil: [ false ] 
		ifNotNil: [ 
			aContext isDead not and: [
				aContext ~= self process suspendedContext or: [aContext willReturn not ] ] ]! !

!GTSUnitDebugSession methodsFor: 'testing' stamp: 'AndreiChis 2/16/2016 14:56'!
overridesDefaultSetOrTearMethods
	
	^ self overridesDefaultTearDownMethod or: [ 
		self overridesDefaultSetUpMethod ]! !

!GTSUnitDebugSession methodsFor: 'testing' stamp: 'AndreiChis 2/16/2016 14:56'!
overridesDefaultSetUpMethod
	
	^ self setUpMethod methodClass ~= TestCase! !

!GTSUnitDebugSession methodsFor: 'testing' stamp: 'AndreiChis 2/16/2016 14:56'!
overridesDefaultTearDownMethod
	
	^ self tearDownMethod methodClass ~= TestCase! !

!GTSUnitDebugSession methodsFor: 'initialization' stamp: 'AndreiChis 1/22/2016 17:02'!
process: aProcess context: aContext

	super process: aProcess context: aContext.

	assertionContext ifNil: [
		self initializeTestContextFrom: aContext.
		self initializeAssestionContextFrom: aContext.
		self supportsDiff ifTrue: [ 
			actualResult := assertionContext tempAt: 1.
			expectedResult := assertionContext tempAt: 2 ]  ]! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 12/29/2015 17:12'!
setUpMethod

	^ self testObject class lookupSelector: #setUp! !

!GTSUnitDebugSession methodsFor: 'testing' stamp: 'AndreiChis 1/22/2016 17:16'!
supportsDiff

	^ assertionContext 
		ifNil: [ false ]
		ifNotNil: [ assertionContext selector = #assert:equals: ]! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 12/29/2015 17:13'!
tearDownMethod

	^ self testObject class lookupSelector: #tearDown! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 22:53'!
testContext

	^ testContext! !

!GTSUnitDebugSession methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 22:53'!
testObject

	^ testContext receiver! !

DebugAction subclass: #GTSUnitDebuggerJumpToTestAction
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitDebuggerJumpToTestAction commentStamp: 'AndreiChis 1/22/2016 14:32' prior: 0!
I implement a debugging action for selecting in the stack the context containing the test  method.
  
I am only valid if the context that triggered the failed assertion is diffferent than the context containing the test method (e.g., the assertion method was called from an utility method of the test)!

!GTSUnitDebuggerJumpToTestAction class methodsFor: 'as yet unclassified' stamp: 'AndreiChis 1/20/2016 23:19'!
gtDebuggerActionFor: aDebugger
	<gtStackDebuggingAction>
	
	^ (self forDebugger: aDebugger)! !

!GTSUnitDebuggerJumpToTestAction methodsFor: 'testing' stamp: 'AndreiChis 1/22/2016 17:17'!
appliesToDebugger: aDebugger

	^ aDebugger session class = GTSUnitDebugSession and: [ 
		aDebugger session assertionCallerContext notNil and: [ 
			aDebugger session testContext ~= aDebugger session assertionCallerContext ] ]! !

!GTSUnitDebuggerJumpToTestAction methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 23:13'!
defaultLabel

	^ 'Jump to test method'! !

!GTSUnitDebuggerJumpToTestAction methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 23:14'!
defaultOrder

	^ 10! !

!GTSUnitDebuggerJumpToTestAction methodsFor: 'actions' stamp: 'AndreiChis 1/20/2016 23:23'!
executeAction
	self debugger stackPresentation selection: self debugger session testContext! !

!GTSUnitDebuggerJumpToTestAction methodsFor: 'accessing' stamp: 'AndreiChis 1/20/2016 23:14'!
id

	^ GTSUnitDebuggerJumpToTestAction name! !

!GTSUnitDebuggerJumpToTestAction methodsFor: 'as yet unclassified' stamp: 'AndreiChis 1/20/2016 23:23'!
initialize
	super initialize.
	self needsUpdate: false! !

GTGenericStackDebugger subclass: #GTSUnitDebugger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitDebugger commentStamp: 'AndreiChis 12/30/2015 10:48' prior: 0!
I am a custom debugger for SUnit.
I embed a textual diff when an #assert:equals: assertion fails and provide access to the setUp/tearDown methods of a test.
!

!GTSUnitDebugger class methodsFor: 'testing' stamp: 'AndreiChis 11/27/2015 18:55'!
availableAutomatically
	"Should this debugger be taken into account when looking for a debugger to handle an exception."
	
	^ true! !

!GTSUnitDebugger class methodsFor: 'accessing' stamp: 'AndreiChis 1/10/2016 17:43'!
defaultTitle

	^ 'SUnit'! !

!GTSUnitDebugger class methodsFor: 'testing' stamp: 'AndreiChis 12/29/2015 17:00'!
handlesContext: aContext
	| activationPredicate |
	activationPredicate := self sessionClass activationPredicate.
	^ (aContext stackOfSize: self lookupStackSize) 
		anySatisfy: [ :ctx | activationPredicate matches: ctx ] ! !

!GTSUnitDebugger class methodsFor: 'accessing' stamp: 'AndreiChis 1/25/2016 00:03'!
helpClass
	^ GTSUnitDebuggerHelp! !

!GTSUnitDebugger class methodsFor: 'testing' stamp: 'AndreiChis 2/16/2016 15:20'!
lookupStackSize
	^ 512! !

!GTSUnitDebugger class methodsFor: 'tools registry' stamp: 'AndreiChis 12/31/2013 21:01'!
register

	self registerToolsOn: Smalltalk tools.! !

!GTSUnitDebugger class methodsFor: 'tools registry' stamp: 'AndreiChis 12/4/2013 12:14'!
registerToolsOn: registry

	"Add ourselves to registry. See [Smalltalk tools]" 
	registry registerDebugger: self withRank: 70.! !

!GTSUnitDebugger class methodsFor: 'accessing' stamp: 'AndreiChis 12/4/2013 12:14'!
sessionClass

	^ GTSUnitDebugSession! !

!GTSUnitDebugger methodsFor: 'as yet unclassified' stamp: 'AndreiChis 2/15/2016 20:27'!
browser 

	^ self presentations first cachedPresentation ifNotNil: [ :aComposite | aComposite presentations first ]! !

!GTSUnitDebugger methodsFor: 'as yet unclassified' stamp: 'AndreiChis 2/16/2016 13:46'!
compose
	"give the window a dedicated reddish color to ensure it gets noticed"
	self class enableDebuggerWindowDistinctColor ifTrue: [ 
		self color: (Color r: 1.0 g: 0.3 b: 0.3) ].
	self installDebuggingActionsFor: self.
	self dynamic display: [ :session |
		GLMTabulator new 
			with: [ :browser | 
				self debuggerStructureIn: browser.
				self debuggerTransmissionsIn: browser ];
			startOn: session;
			yourself ].
	self registerActions! !

!GTSUnitDebugger methodsFor: 'accessing context' stamp: 'AndreiChis 1/22/2016 17:16'!
contextToSelectFrom: aSession
	^ aSession assertionCallerContext ifNil: [ aSession testContext ]! !

!GTSUnitDebugger methodsFor: 'building' stamp: 'AndreiChis 2/16/2016 13:37'!
debuggerStructureIn: browser
	
	browser
		row: #stack;
		row: [ :c | c
			column: #code.
			self shouldDisplayExtraCodePane ifTrue: [ 
				c column: #test ] ] span: 2;
		row: #inspector.
		! !

!GTSUnitDebugger methodsFor: 'building' stamp: 'AndreiChis 2/16/2016 13:47'!
debuggerTransmissionsIn: browser

	super debuggerTransmissionsIn: browser.
	
	self shouldDisplayExtraCodePane ifTrue: [ 
		browser transmit
			from: #stack port: #selection;
			to: #test;
			andShow: [ :aComposite :aContext | 
				self setUpCodeIn: aComposite.
				self tearDownCodeIn: aComposite ] ]
! !

!GTSUnitDebugger methodsFor: 'building presentations' stamp: 'AndreiChis 1/20/2016 16:51'!
inspectorDiffIn: aComposite

	^ aComposite tabulator 
		with: [ :aTabulator |
			aTabulator when: [ self session supportsDiff].
			aTabulator 
				column: #actual;
				column: #expected.
			aTabulator transmit to: #actual; andShow: [ :anotherComposite |
				anotherComposite  dynamic 
					display: [:anObject |
				 		(GTDebuggerInspector new 
							startOn: self session actualResult) ] ].
			aTabulator transmit to: #expected; andShow: [ :anotherComposite |
				anotherComposite  dynamic 
					display: [:anObject |
				 		(GTDebuggerInspector new 
							startOn: self session expectedResult) ] ] ]! !

!GTSUnitDebugger methodsFor: 'building presentations' stamp: 'AndreiChis 1/20/2016 16:56'!
inspectorIn: aComposite

	(self textualDiffIn: aComposite) title: 'Diff (actual vs. expected)'.
	(self inspectorDiffIn: aComposite) title: 'Objects (actual vs. expected)'.
	super inspectorIn: aComposite.
	self session supportsDiff ifTrue: [ 
		aComposite last title: 'Inspector' ]! !

!GTSUnitDebugger methodsFor: 'as yet unclassified' stamp: 'AndreiChis 2/16/2016 13:57'!
session
 
	^ self entity! !

!GTSUnitDebugger methodsFor: 'as yet unclassified' stamp: 'AndreiChis 2/15/2016 20:24'!
session: aSession
	self startOn: aSession.
	self title: aSession name! !

!GTSUnitDebugger methodsFor: 'building presentations' stamp: 'AndreiChis 2/16/2016 16:49'!
setUpCodeIn: aComposite

	aComposite pharoMethod
		title: [ self setUpPresentationTitle ];
		format: [ self session setUpMethod sourceCode ];
		smalltalkClass: [  self session testObject class ];
		when: [ self session overridesDefaultSetUpMethod ];
		doItReceiver: [ self session testObject ].! !

!GTSUnitDebugger methodsFor: 'accessing context' stamp: 'AndreiChis 2/16/2016 16:49'!
setUpPresentationTitle

	^ 'SetUp', 
		(self session setUpMethod methodClass ~= self session testContext methodClass
			ifTrue: [ ' (', self session setUpMethod methodClass name,')' ]
			ifFalse: [ '' ])! !

!GTSUnitDebugger methodsFor: 'building' stamp: 'AndreiChis 2/16/2016 13:44'!
shouldDisplayExtraCodePane

	^ self session overridesDefaultSetOrTearMethods! !

!GTSUnitDebugger methodsFor: 'building presentations' stamp: 'AndreiChis 2/16/2016 16:49'!
tearDownCodeIn: aComposite

	aComposite pharoMethod
		title: [ self tearDownPresentationTitle ];
		format: [ self session tearDownMethod sourceCode ];
		smalltalkClass: [  self session testObject class ];
		when: [ self session overridesDefaultTearDownMethod ];
		doItReceiver: [ self session testObject ].! !

!GTSUnitDebugger methodsFor: 'accessing context' stamp: 'AndreiChis 2/16/2016 16:48'!
tearDownPresentationTitle

	^ 'TearDown', 
		(self session tearDownMethod methodClass ~= self session testContext methodClass
			ifTrue: [ ' (', self session tearDownMethod methodClass name,')' ]
			ifFalse: [ '' ])! !

!GTSUnitDebugger methodsFor: 'building presentations' stamp: 'AndreiChis 1/20/2016 16:41'!
textualDiffIn: composite

	^ composite diff
			when: [ self session supportsDiff];
			display: [ 
				{self session actualResult gtDebuggerSUnitPrint. self session expectedResult gtDebuggerSUnitPrint} ]! !

!GTSUnitDebugger methodsFor: 'updating' stamp: 'AndreiChis 11/30/2015 23:32'!
updateBrowser

	super updateBrowser.
	"The transmission will select the context of the test case. 
	This should only happen the first time.
	Should find another solution so this method doesn;t have to be overridden"
	((self browser paneNamed: #stack) port: #selection) value: self session interruptedContext! !

!Collection methodsFor: '*GT-SUnitDebugger' stamp: 'AndreiChis 12/28/2015 20:22'!
gtDebuggerSUnitPrint

	^ String streamContents: [:s | self asStringOn: s delimiter: Character cr asString]! !

TestCase subclass: #GTSUnitExampleFailingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitExampleFailingTest commentStamp: 'AndreiChis 12/30/2015 10:39' prior: 0!
I am not a test!! I provide usage examples for the SUnit debugger.!

!GTSUnitExampleFailingTest class methodsFor: 'testing' stamp: 'AndreiChis 1/19/2014 13:32'!
isAbstract
	^ true! !

!GTSUnitExampleFailingTest class methodsFor: 'testing' stamp: 'AndreiChis 11/27/2015 18:14'!
isUnitTest
	^ false! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'TudorGirba 1/20/2016 20:54'!
checkWithFailure
	self assert: false description: 'A failure'! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'TudorGirba 1/20/2016 20:55'!
intermediaryCheckWithFailure
	40 + 2.
	self checkWithFailure! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'AndreiChis 3/26/2014 16:02'!
testArrays
	 self
           assert: #(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 
49 50 51 51 51 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 
75 76 77 78 79 80 81 81 81 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99)
           equals: #(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99)! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'AndreiChis 3/26/2014 16:17'!
testDictionary
	 self
		assert: (#(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 
49 50 51 51 51 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 
75 76 77 78 79 80 81 81 81 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101) inject: Dictionary new into: [ :dict :nr| dict at: nr put: nr<<5. dict ])
      equals: (#(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101) inject: Dictionary new into: [ :dict :nr| 
		nr\\40 == 0 
			ifTrue: [ dict at: nr put: nr<<6 ]
			ifFalse: [ dict at: nr put: nr<<5 ].
			dict ])! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'TudorGirba 1/20/2016 20:54'!
testFailingAssestionThroughAHelperMethod

	self intermediaryCheckWithFailure! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'AndreiChis 3/26/2014 16:01'!
testFailingDate
	|aDateAndTime|

	aDateAndTime :=  DateAndTime localTimeZone: TimeZone default; dosEpoch.
	self 
		assert: (aDateAndTime offset: '0:12:00:00')  
		equals: '1 January 1980 1:00 pm' asDateAndTime! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'AndreiChis 12/29/2013 18:28'!
testFailingText

	self assert: 'I like pie  
pizza pie 
apple pie 
rad squared pi 
and other PIes'
	equals: 'I like pie  
pizza pie 
potato pie 
rad squared pi 
and other PIes'! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'AndreiChis 12/17/2013 10:50'!
testMultiValuedStreaming
	| headers keysAndValues |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	headers at: 'Content-TYPE' put: 'text/plain'.
	headers at: 'Content-Length' put: '128'.
	keysAndValues := OrderedCollection streamContents: [ : stream |
		headers headersDo: [ :key :value |
			stream nextPut: key; nextPut: value ] ].
	self assert: keysAndValues equals: #('Set-Cookie' 'foo=1' 'Set-Cookie' 'bar=1' 'Content-Length' '128' 'Content-TYPE' 'text/plain') asOrderedCollection 
	
	! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'AndreiChis 1/20/2016 16:06'!
testSimpleFailingAssestion

	self assert: false! !

!GTSUnitExampleFailingTest methodsFor: 'tests' stamp: 'TudorGirba 1/22/2016 12:17'!
testWithHalt

	self assert: true.
	self halt! !

TestCase subclass: #GTSUnitExampleWithProblematicSetUpTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitExampleWithProblematicSetUpTest commentStamp: 'TudorGirba 2/15/2016 13:40' prior: 0!
I am not a test!! I provide usage examples for the SUnit debugger.!

!GTSUnitExampleWithProblematicSetUpTest class methodsFor: 'testing' stamp: 'TudorGirba 2/15/2016 13:40'!
isAbstract
	^ true! !

!GTSUnitExampleWithProblematicSetUpTest class methodsFor: 'testing' stamp: 'TudorGirba 2/15/2016 13:40'!
isUnitTest
	^ false! !

!GTSUnitExampleWithProblematicSetUpTest methodsFor: 'setup' stamp: 'TudorGirba 2/8/2016 14:18'!
setUp
	42 messageThatIsNotUnderstood! !

!GTSUnitExampleWithProblematicSetUpTest methodsFor: 'testing' stamp: 'TudorGirba 2/8/2016 14:19'!
testWithErrorInSetup
	self assert: true! !

GTDebuggerHelp subclass: #GTSUnitDebuggerHelp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-SUnitDebugger'!

!GTSUnitDebuggerHelp commentStamp: 'AndreiChis 1/25/2016 10:14' prior: 0!
A utility class containing the help for GT SUnitDebugger.!

!GTSUnitDebuggerHelp class methodsFor: 'accessing' stamp: 'AndreiChis 1/25/2016 00:02'!
bookName 
	^'SUnit'! !

!GTSUnitDebuggerHelp class methodsFor: 'documentation' stamp: 'AndreiChis 1/25/2016 10:13'!
overview
	^ HelpTopic 
		title: 'Overview'
		contents: 
'GT SUnit is an extension for GT Debugger providing support for debugging tests.'! !

!GTSUnitDebuggerHelp class methodsFor: 'accessing' stamp: 'AndreiChis 1/25/2016 11:09'!
pages
	^#(overview actions)! !
